Package: metalite.sl
Title: Subject-Level Analysis Using 'metalite'
Version: 0.1.3
Authors@R: c(
    person("Yujie", "Zhao", email = "yujie.zhao@merck.com", role = c("aut", "cre")),
    person("Benjamin", "Wang", email = "benjamin.wang@merck.com", role = "aut"),
    person("Hiroaki", "Fukuda", role = "aut"),
    person("PoYao", "Niu", role = "aut"),
    person("Nan", "Xiao", role = "aut"),
    person("Jeetener", "Chauhan", role = "ctb"),
    person("Li", "Ma", role = "ctb"),
    person("Chen", "Wang", role = "ctb"),
    person("Merck Sharp & Dohme Corp", role = "cph")
    )
Description: Analyzes subject-level data in clinical trials using the 'metalite'
    data structure. The package simplifies the workflow to create
    production-ready tables, listings, and figures discussed in the
    subject-level analysis chapters of
    "R for Clinical Study Reports and Submission"
    by Zhang et al. (2022) <https://r4csr.org/>.
Depends: R (>= 4.1.0)
License: GPL (>= 3)
URL: https://merck.github.io/metalite.sl/,
        https://github.com/Merck/metalite.sl
Imports: glue, metalite, metalite.ae, r2rtf, reactable, stringr, rlang,
        plotly, htmltools, brew, uuid, htmlwidgets
Suggests: dplyr, knitr, testthat (>= 3.0.0), tidyr
VignetteBuilder: knitr
Encoding: UTF-8
RoxygenNote: 7.3.3
Config/testthat/edition: 3
LazyData: true
NeedsCompilation: no
Packaged: 2026-08-26 13:43:10 UTC; zhayuji4
Author: Yujie Zhao [aut, cre],
  Benjamin Wang [aut],
  Hiroaki Fukuda [aut],
  PoYao Niu [aut],
  Nan Xiao [aut],
  Jeetener Chauhan [ctb],
  Li Ma [ctb],
  Chen Wang [ctb],
  Merck Sharp & Dohme Corp [cph]
Maintainer: Yujie Zhao <yujie.zhao@merck.com>
Repository: CRAN
Date/Publication: 2026-08-26 14:50:02 UTC
