# rtf output: n, and prop, NO total. With 2 decimal places.

    Code
      writeLines(rtf_content)
    Output
      {\rtf1\ansi
      \deff0\deflang1033
      {\fonttbl{\f0\froman\fcharset1\fprq2 Times New Roman;}
      {\f1\froman\fcharset161\fprq2 Times New Roman Greek;}
      {\f2\fswiss\fcharset161\fprq2 Arial Greek;}
      {\f3\fswiss\fcharset0\fprq2 Arial;}
      {\f4\fswiss\fcharset1\fprq2 Helvetica;}
      {\f5\fswiss\fcharset1\fprq2 Calibri;}
      {\f6\froman\fcharset1\fprq2 Georgia;}
      {\f7\ffroman\fcharset1\fprq2 Cambria;}
      {\f8\fmodern\fcharset0\fprq2 Courier New;}
      {\f9\ftech\fcharset2\fprq2 Symbol;}
      }
      
      
      \paperw12240\paperh15840
      
      \margl1800\margr1440\margt2520\margb1800\headery2520\footery1449
      
      {\pard\hyphpar\sb180\sa180\fi0\li0\ri0\qc\fs24{\f0 Summary of Exposure Duration}\line\fs24{\f0 All Participants as Treated}\par}
      
      
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrb\brdrw15\clvertalb\cellx3000
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrb\brdrw15\clvertalb\cellx5000
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrb\brdrw15\clvertalb\cellx7000
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx9000
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 Placebo}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 Low Dose}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 High Dose}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalb\cellx3000
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx4000
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx5000
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx6000
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx7000
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx8000
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx9000
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (%)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3000
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4000
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5000
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6000
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7000
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8000
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9000
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs18{\f0 Participants in population}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 86}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 84}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 84}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx9000
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs18{\f0\b Exposure Duration (Days)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3000
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4000
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5000
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6000
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7000
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8000
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9000
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 \uc1\u8805* 1 day and <7 days}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 1}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0  (1.16)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 3}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0  (3.57)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 2}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0  (2.38)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3000
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4000
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5000
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6000
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7000
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8000
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9000
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 \uc1\u8805* 7 days and <28 days}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 13}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (15.12)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 10}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (11.90)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 14}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (16.67)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3000
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4000
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5000
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6000
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7000
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8000
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9000
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 \uc1\u8805* 28 days and <12 weeks}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 28}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (32.56)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 26}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (30.95)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 24}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (28.57)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3000
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4000
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5000
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6000
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7000
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8000
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9000
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 \uc1\u8805* 12 weeks and <24 weeks}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 43}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (50.00)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 44}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (52.38)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 43}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (51.19)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3000
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4000
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5000
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6000
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7000
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8000
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9000
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 \uc1\u8805* 24 weeks}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 1}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0  (1.16)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 1}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0  (1.19)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 1}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0  (1.19)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3000
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4000
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5000
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6000
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7000
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8000
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9000
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3000
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4000
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5000
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6000
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7000
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8000
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9000
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 Mean}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 87.2}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 89.8}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 83.6}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3000
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4000
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5000
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6000
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7000
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8000
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9000
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 SD}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 50.1}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 50.2}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 48.9}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3000
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4000
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5000
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6000
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7000
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8000
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9000
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 SE}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 5.4}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 5.5}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 5.3}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3000
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4000
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5000
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6000
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7000
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8000
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9000
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 Median}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 85.0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 90.0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 87.0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3000
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4000
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5000
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6000
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7000
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8000
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9000
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 Q1 to Q3}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 36.75 to 129.75}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 52 to 135}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 41.5 to 128.75}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx3000
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx4000
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx5000
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx6000
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx7000
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx8000
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx9000
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 Range}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 6 to 168}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 1 to 168}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 4 to 168}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrdb\brdrw15\clvertalt\cellx9000
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs18{\f0 SD=Standard deviation; SE=Standard error; Q1=First quartile, Q3=Third quartile.\line Each participant is counted once on each applicable duration category row.\line Duration of Exposure is the time from the first dose date to the last dose date.}\cell
      \intbl\row\pard
      {\pard\hyphpar\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 Source: [CDISCpilot: adam-adexsum]}\par}
      
      }

# rtf output: n, prop and total, with Landscape

    Code
      writeLines(rtf_content)
    Output
      {\rtf1\ansi
      \deff0\deflang1033
      {\fonttbl{\f0\froman\fcharset1\fprq2 Times New Roman;}
      {\f1\froman\fcharset161\fprq2 Times New Roman Greek;}
      {\f2\fswiss\fcharset161\fprq2 Arial Greek;}
      {\f3\fswiss\fcharset0\fprq2 Arial;}
      {\f4\fswiss\fcharset1\fprq2 Helvetica;}
      {\f5\fswiss\fcharset1\fprq2 Calibri;}
      {\f6\froman\fcharset1\fprq2 Georgia;}
      {\f7\ffroman\fcharset1\fprq2 Cambria;}
      {\f8\fmodern\fcharset0\fprq2 Courier New;}
      {\f9\ftech\fcharset2\fprq2 Symbol;}
      }
      
      
      \paperw15840\paperh12240\landscape
      
      \margl1440\margr1440\margt2880\margb1800\headery1800\footery1800
      
      {\pard\hyphpar\sb180\sa180\fi0\li0\ri0\qc\fs24{\f0 Summary of Exposure Duration}\line\fs24{\f0 All Participants as Treated}\par}
      
      
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrb\brdrw15\clvertalb\cellx3338
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrb\brdrw15\clvertalb\cellx5563
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrb\brdrw15\clvertalb\cellx7788
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrb\brdrw15\clvertalb\cellx10013
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx12238
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 Placebo}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 Low Dose}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 High Dose}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 Total}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalb\cellx3338
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx4451
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx5564
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx6677
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx7790
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx8903
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx10016
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx11129
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx12242
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (%)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3338
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4451
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5564
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6677
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7790
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8903
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10016
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11129
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12242
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs18{\f0 Participants in population}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 86}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 84}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 84}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 254}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs18{\f0\b Exposure Duration (Days)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3338
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4451
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5564
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6677
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7790
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8903
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10016
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11129
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12242
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 \uc1\u8805* 1 day and <7 days}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 1}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0  (1.2)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 3}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0  (3.6)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 2}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0  (2.4)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 6}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0  (2.4)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3338
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4451
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5564
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6677
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7790
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8903
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10016
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11129
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12242
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 \uc1\u8805* 7 days and <28 days}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 13}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (15.1)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 10}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (11.9)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 14}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (16.7)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 37}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (14.6)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3338
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4451
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5564
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6677
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7790
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8903
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10016
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11129
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12242
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 \uc1\u8805* 28 days and <12 weeks}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 28}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (32.6)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 26}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (31.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 24}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (28.6)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 78}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (30.7)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3338
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4451
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5564
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6677
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7790
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8903
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10016
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11129
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12242
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 \uc1\u8805* 12 weeks and <24 weeks}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 43}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (50.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 44}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (52.4)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 43}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (51.2)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 130}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (51.2)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3338
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4451
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5564
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6677
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7790
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8903
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10016
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11129
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12242
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 \uc1\u8805* 24 weeks}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 1}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0  (1.2)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 1}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0  (1.2)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 1}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0  (1.2)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 3}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0  (1.2)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3338
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4451
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5564
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6677
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7790
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8903
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10016
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11129
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12242
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3338
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4451
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5564
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6677
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7790
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8903
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10016
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11129
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12242
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 Mean}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 87.2}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 89.8}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 83.6}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 86.9}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3338
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4451
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5564
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6677
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7790
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8903
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10016
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11129
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12242
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 SD}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 50.1}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 50.2}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 48.9}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 49.6}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx3338
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx4451
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx5564
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx6677
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx7790
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx8903
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx10016
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx11129
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx12242
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 SE}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 5.4}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 5.5}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 5.3}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 3.1}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \intbl\row\pard
      
      
      {\pard\fs2\par}\page{\pard\fs2\par}
      \paperw15840\paperh12240\landscape
      
      \margl1440\margr1440\margt2880\margb1800\headery1800\footery1800
      
      {\pard\hyphpar\sb180\sa180\fi0\li0\ri0\qc\fs24{\f0 Summary of Exposure Duration}\line\fs24{\f0 All Participants as Treated}\par}
      
      
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx3338
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx5563
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx7788
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx10013
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx12238
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 Placebo}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 Low Dose}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 High Dose}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 Total}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalb\cellx3338
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx4451
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx5564
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx6677
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx7790
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx8903
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx10016
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx11129
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx12242
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (%)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs18{\f0\b Exposure Duration (Days)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3338
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4451
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5564
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6677
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7790
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8903
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10016
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11129
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12242
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 Median}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 85.0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 90.0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 87.0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 87.0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3338
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4451
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5564
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6677
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7790
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8903
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10016
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11129
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12242
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 Q1 to Q3}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 36.75 to 129.75}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 52 to 135}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 41.5 to 128.75}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 43.5 to 134}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx3338
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx4451
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx5564
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx6677
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx7790
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx8903
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx10016
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx11129
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx12242
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 Range}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 6 to 168}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 1 to 168}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 4 to 168}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 1 to 168}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrdb\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs18{\f0 SD=Standard deviation; SE=Standard error; Q1=First quartile, Q3=Third quartile.\line Each participant is counted once on each applicable duration category row.\line Duration of Exposure is the time from the first dose date to the last dose date.}\cell
      \intbl\row\pard
      {\pard\hyphpar\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 Source: [CDISCpilot: adam-adexsum]}\par}
      
      }

# rtf output: n, prop and total, with no value of col_rel_width

    Code
      writeLines(rtf_content)
    Output
      {\rtf1\ansi
      \deff0\deflang1033
      {\fonttbl{\f0\froman\fcharset1\fprq2 Times New Roman;}
      {\f1\froman\fcharset161\fprq2 Times New Roman Greek;}
      {\f2\fswiss\fcharset161\fprq2 Arial Greek;}
      {\f3\fswiss\fcharset0\fprq2 Arial;}
      {\f4\fswiss\fcharset1\fprq2 Helvetica;}
      {\f5\fswiss\fcharset1\fprq2 Calibri;}
      {\f6\froman\fcharset1\fprq2 Georgia;}
      {\f7\ffroman\fcharset1\fprq2 Cambria;}
      {\f8\fmodern\fcharset0\fprq2 Courier New;}
      {\f9\ftech\fcharset2\fprq2 Symbol;}
      }
      
      
      \paperw12240\paperh15840
      
      \margl1800\margr1440\margt2520\margb1800\headery2520\footery1449
      
      {\pard\hyphpar\sb180\sa180\fi0\li0\ri0\qc\fs24{\f0 Summary of Exposure Duration}\line\fs24{\f0 All Participants as Treated}\par}
      
      
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrb\brdrw15\clvertalb\cellx1636
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrb\brdrw15\clvertalb\cellx3272
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrb\brdrw15\clvertalb\cellx4908
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrb\brdrw15\clvertalb\cellx6544
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx8999
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 Placebo}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 Low Dose}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 High Dose}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 Total}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalb\cellx1636
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx2454
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx3272
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx4090
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx4908
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx5726
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx6544
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx7771
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx8998
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (%)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1636
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2454
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3272
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4090
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4908
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5726
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6544
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7771
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8998
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs18{\f0 Participants in population}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 86}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 84}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 84}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 254}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx9000
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs18{\f0\b Exposure Duration (Days)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1636
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2454
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3272
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4090
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4908
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5726
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6544
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7771
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8998
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 \uc1\u8805* 1 day and <7 days}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 1}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0  (1.2)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 3}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0  (3.6)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 2}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0  (2.4)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 6}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0  (2.4)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1636
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2454
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3272
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4090
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4908
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5726
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6544
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7771
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8998
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 \uc1\u8805* 7 days and <28 days}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 13}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (15.1)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 10}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (11.9)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 14}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (16.7)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 37}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (14.6)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1636
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2454
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3272
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4090
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4908
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5726
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6544
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7771
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8998
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 \uc1\u8805* 28 days and <12 weeks}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 28}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (32.6)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 26}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (31.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 24}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (28.6)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 78}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (30.7)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1636
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2454
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3272
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4090
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4908
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5726
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6544
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7771
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8998
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 \uc1\u8805* 12 weeks and <24 weeks}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 43}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (50.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 44}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (52.4)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 43}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (51.2)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 130}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (51.2)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1636
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2454
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3272
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4090
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4908
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5726
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6544
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7771
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8998
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 \uc1\u8805* 24 weeks}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 1}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0  (1.2)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 1}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0  (1.2)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 1}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0  (1.2)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 3}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0  (1.2)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1636
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2454
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3272
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4090
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4908
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5726
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6544
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7771
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8998
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1636
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2454
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3272
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4090
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4908
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5726
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6544
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7771
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8998
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 Mean}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 87.2}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 89.8}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 83.6}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 86.9}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1636
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2454
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3272
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4090
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4908
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5726
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6544
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7771
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8998
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 SD}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 50.1}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 50.2}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 48.9}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 49.6}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1636
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2454
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3272
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4090
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4908
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5726
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6544
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7771
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8998
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 SE}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 5.4}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 5.5}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 5.3}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 3.1}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1636
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2454
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3272
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4090
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4908
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5726
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6544
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7771
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8998
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 Median}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 85.0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 90.0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 87.0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 87.0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1636
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2454
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3272
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4090
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4908
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5726
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6544
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7771
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8998
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 Q1 to Q3}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 36.75 to 129.75}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 52 to 135}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 41.5 to 128.75}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 43.5 to 134}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx1636
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx2454
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx3272
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx4090
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx4908
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx5726
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx6544
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx7771
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx8998
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 Range}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 6 to 168}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 1 to 168}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 4 to 168}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 1 to 168}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrdb\brdrw15\clvertalt\cellx9000
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs18{\f0 SD=Standard deviation; SE=Standard error; Q1=First quartile, Q3=Third quartile.\line Each participant is counted once on each applicable duration category row.\line Duration of Exposure is the time from the first dose date to the last dose date.}\cell
      \intbl\row\pard
      {\pard\hyphpar\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 Source: [CDISCpilot: adam-adexsum]}\par}
      
      }

