# rtf output: n and prop including subgroup total w/o total

    Code
      writeLines(rtf_content)
    Output
      {\rtf1\ansi
      \deff0\deflang1033
      {\fonttbl{\f0\froman\fcharset1\fprq2 Times New Roman;}
      {\f1\froman\fcharset161\fprq2 Times New Roman Greek;}
      {\f2\fswiss\fcharset161\fprq2 Arial Greek;}
      {\f3\fswiss\fcharset0\fprq2 Arial;}
      {\f4\fswiss\fcharset1\fprq2 Helvetica;}
      {\f5\fswiss\fcharset1\fprq2 Calibri;}
      {\f6\froman\fcharset1\fprq2 Georgia;}
      {\f7\ffroman\fcharset1\fprq2 Cambria;}
      {\f8\fmodern\fcharset0\fprq2 Courier New;}
      {\f9\ftech\fcharset2\fprq2 Symbol;}
      }
      
      
      \paperw15840\paperh12240\landscape
      
      \margl1440\margr1440\margt2880\margb1800\headery1800\footery1800
      
      {\pard\hyphpar\sb180\sa180\fi0\li0\ri0\qc\fs24{\f0 Participant by Age Category and Sex}\line\fs24{\f0 All Participants as Treated}\par}
      
      
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrb\brdrw15\clvertalb\cellx1360
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrb\brdrw15\clvertalb\cellx4080
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrb\brdrw15\clvertalb\cellx6800
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrb\brdrw15\clvertalb\cellx9520
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx12240
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Placebo}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Low Dose}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 High Dose}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Total}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalb\cellx1360
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx2720
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx4080
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx5440
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx6800
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx8160
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx9520
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx10880
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx12240
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Female}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Male}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Female}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Male}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Female}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Male}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Female}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Male}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalb\cellx1360
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx2040
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx2720
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx3400
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx4080
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx4760
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx5440
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx6120
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx6800
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx7480
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx8160
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx8840
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx9520
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx10200
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx10880
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx11560
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx12240
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1360
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2040
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2720
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3400
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4080
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4760
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5440
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6120
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6800
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7480
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8160
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8840
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9520
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10200
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10880
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11560
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 Participants in population}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 53}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 33}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 50}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 34}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 40}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 44}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 143}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 111}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 Age (years)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1360
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2040
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2720
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3400
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4080
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4760
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5440
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6120
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6800
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7480
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8160
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8840
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9520
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10200
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10880
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11560
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs16{\f0 <65}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 9}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (17.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 5}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (15.2)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 5}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (10.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 3}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  (8.8)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 5}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (12.5)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 6}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (13.6)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 19}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (13.3)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 14}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (12.6)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1360
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2040
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2720
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3400
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4080
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4760
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5440
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6120
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6800
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7480
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8160
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8840
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9520
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10200
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10880
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11560
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs16{\f0 65-80}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 22}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (41.5)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 20}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (60.6)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 28}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (56.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 19}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (55.9)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 28}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (70.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 27}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (61.4)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 78}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (54.5)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 66}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (59.5)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1360
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2040
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2720
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3400
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4080
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4760
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5440
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6120
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6800
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7480
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8160
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8840
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9520
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10200
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10880
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11560
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs16{\f0 >80}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 22}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (41.5)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 8}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (24.2)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 17}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (34.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 12}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (35.3)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 7}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (17.5)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 11}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (25.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 46}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (32.2)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 31}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (27.9)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1360
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2040
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2720
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3400
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4080
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4760
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5440
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6120
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6800
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7480
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8160
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8840
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9520
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10200
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10880
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11560
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1360
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2040
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2720
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3400
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4080
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4760
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5440
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6120
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6800
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7480
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8160
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8840
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9520
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10200
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10880
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11560
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs16{\f0 Mean}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 76.4}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 73.4}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 75.7}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 75.6}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 74.7}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 74.1}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 75.7}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 74.4}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1360
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2040
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2720
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3400
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4080
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4760
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5440
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6120
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6800
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7480
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8160
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8840
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9520
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10200
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10880
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11560
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs16{\f0 SD}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 8.7}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 8.1}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 8.1}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 8.7}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 7.7}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 8.2}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 8.2}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 8.3}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1360
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2040
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2720
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3400
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4080
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4760
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5440
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6120
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6800
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7480
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8160
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8840
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9520
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10200
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10880
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11560
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs16{\f0 Median}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 78.0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 74.0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 77.5}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 77.5}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 76.0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 77.0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 77.0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 77.0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx1360
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx2040
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx2720
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx3400
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx4080
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx4760
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx5440
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx6120
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx6800
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx7480
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx8160
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx8840
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx9520
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx10200
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx10880
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx11560
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs16{\f0 Range}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 59 to 89}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 52 to 85}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 54 to 87}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 51 to 88}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 56 to 88}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 56 to 86}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 54 to 89}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 51 to 88}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrdb\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 SD=Standard deviation.}\cell
      \intbl\row\pard
      {\pard\hyphpar\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Source:  [CDISCpilot: adam-adsl]}\par}
      
      }

# rtf output: n and prop including subgroup total w/ total

    Code
      writeLines(rtf_content)
    Output
      {\rtf1\ansi
      \deff0\deflang1033
      {\fonttbl{\f0\froman\fcharset1\fprq2 Times New Roman;}
      {\f1\froman\fcharset161\fprq2 Times New Roman Greek;}
      {\f2\fswiss\fcharset161\fprq2 Arial Greek;}
      {\f3\fswiss\fcharset0\fprq2 Arial;}
      {\f4\fswiss\fcharset1\fprq2 Helvetica;}
      {\f5\fswiss\fcharset1\fprq2 Calibri;}
      {\f6\froman\fcharset1\fprq2 Georgia;}
      {\f7\ffroman\fcharset1\fprq2 Cambria;}
      {\f8\fmodern\fcharset0\fprq2 Courier New;}
      {\f9\ftech\fcharset2\fprq2 Symbol;}
      }
      
      
      \paperw15840\paperh12240\landscape
      
      \margl1440\margr1440\margt2880\margb1800\headery1800\footery1800
      
      {\pard\hyphpar\sb180\sa180\fi0\li0\ri0\qc\fs24{\f0 Participant by Age Category and Sex}\line\fs24{\f0 All Participants as Treated}\par}
      
      
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrb\brdrw15\clvertalb\cellx942
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrb\brdrw15\clvertalb\cellx3767
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrb\brdrw15\clvertalb\cellx6592
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrb\brdrw15\clvertalb\cellx9417
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx12242
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Placebo}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Low Dose}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 High Dose}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Total}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalb\cellx942
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx1884
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx2826
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx3768
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx4710
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx5652
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx6594
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx7536
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx8478
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx9420
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx10362
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx11304
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx12246
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Female}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Male}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Total}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Female}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Male}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Total}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Female}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Male}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Total}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Female}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Male}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Total}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalb\cellx942
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx1413
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx1884
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx2355
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx2826
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx3297
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx3768
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx4239
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx4710
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx5181
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx5652
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx6123
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx6594
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx7065
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx7536
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx8007
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx8478
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx8949
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx9420
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx9891
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx10362
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx10833
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx11304
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx11775
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx12246
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx942
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1413
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1884
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2355
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2826
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3297
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3768
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4239
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4710
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5181
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5652
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6123
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6594
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7065
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7536
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8007
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8478
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8949
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9420
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9891
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10362
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10833
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11304
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11775
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12246
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 Participants in population}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 53}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 33}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 86}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 50}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 34}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 84}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 40}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 44}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 84}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 143}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 111}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 254}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 Age (years)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx942
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1413
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1884
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2355
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2826
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3297
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3768
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4239
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4710
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5181
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5652
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6123
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6594
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7065
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7536
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8007
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8478
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8949
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9420
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9891
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10362
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10833
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11304
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11775
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12246
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs16{\f0 <65}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 9}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (17.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 5}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (15.2)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 14}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (16.3)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 5}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (10.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 3}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  (8.8)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 8}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  (9.5)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 5}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (12.5)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 6}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (13.6)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 11}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (13.1)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 19}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (13.3)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 14}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (12.6)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 33}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (13.0)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx942
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1413
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1884
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2355
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2826
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3297
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3768
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4239
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4710
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5181
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5652
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6123
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6594
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7065
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7536
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8007
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8478
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8949
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9420
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9891
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10362
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10833
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11304
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11775
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12246
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs16{\f0 65-80}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 22}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (41.5)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 20}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (60.6)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 42}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (48.8)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 28}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (56.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 19}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (55.9)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 47}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (56.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 28}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (70.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 27}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (61.4)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 55}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (65.5)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 78}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (54.5)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 66}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (59.5)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 144}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (56.7)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx942
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1413
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1884
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2355
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2826
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3297
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3768
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4239
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4710
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5181
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5652
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6123
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6594
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7065
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7536
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8007
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8478
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8949
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9420
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9891
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10362
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10833
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11304
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11775
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12246
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs16{\f0 >80}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 22}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (41.5)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 8}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (24.2)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 30}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (34.9)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 17}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (34.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 12}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (35.3)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 29}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (34.5)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 7}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (17.5)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 11}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (25.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 18}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (21.4)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 46}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (32.2)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 31}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (27.9)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 77}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (30.3)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx942
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1413
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1884
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2355
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2826
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3297
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3768
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4239
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4710
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5181
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5652
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6123
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6594
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7065
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7536
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8007
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8478
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8949
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9420
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9891
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10362
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10833
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11304
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11775
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12246
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx942
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1413
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1884
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2355
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2826
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3297
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3768
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4239
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4710
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5181
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5652
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6123
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6594
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7065
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7536
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8007
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8478
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8949
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9420
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9891
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10362
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10833
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11304
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11775
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12246
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs16{\f0 Mean}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 76.4}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 73.4}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 75.2}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 75.7}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 75.6}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 75.7}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 74.7}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 74.1}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 74.4}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 75.7}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 74.4}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 75.1}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx942
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1413
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1884
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2355
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2826
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3297
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3768
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4239
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4710
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5181
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5652
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6123
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6594
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7065
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7536
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8007
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8478
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8949
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9420
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9891
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10362
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10833
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11304
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11775
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12246
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs16{\f0 SD}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 8.7}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 8.1}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 8.6}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 8.1}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 8.7}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 8.3}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 7.7}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 8.2}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 7.9}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 8.2}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 8.3}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 8.2}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx942
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1413
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1884
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2355
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2826
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3297
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3768
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4239
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4710
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5181
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5652
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6123
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6594
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7065
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7536
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8007
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8478
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8949
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9420
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9891
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10362
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10833
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11304
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11775
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12246
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs16{\f0 Median}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 78.0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 74.0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 76.0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 77.5}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 77.5}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 77.5}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 76.0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 77.0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 76.0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 77.0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 77.0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 77.0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx942
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx1413
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx1884
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx2355
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx2826
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx3297
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx3768
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx4239
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx4710
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx5181
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx5652
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx6123
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx6594
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx7065
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx7536
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx8007
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx8478
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx8949
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx9420
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx9891
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx10362
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx10833
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx11304
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx11775
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx12246
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs16{\f0 Range}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 59 to 89}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 52 to 85}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 52 to 89}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 54 to 87}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 51 to 88}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 51 to 88}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 56 to 88}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 56 to 86}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 56 to 88}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 54 to 89}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 51 to 88}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 51 to 89}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrdb\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 SD=Standard deviation.}\cell
      \intbl\row\pard
      {\pard\hyphpar\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Source:  [CDISCpilot: adam-adsl]}\par}
      
      }

# rtf output: n and prop not including subgroup total w/o total

    Code
      writeLines(rtf_content)
    Output
      {\rtf1\ansi
      \deff0\deflang1033
      {\fonttbl{\f0\froman\fcharset1\fprq2 Times New Roman;}
      {\f1\froman\fcharset161\fprq2 Times New Roman Greek;}
      {\f2\fswiss\fcharset161\fprq2 Arial Greek;}
      {\f3\fswiss\fcharset0\fprq2 Arial;}
      {\f4\fswiss\fcharset1\fprq2 Helvetica;}
      {\f5\fswiss\fcharset1\fprq2 Calibri;}
      {\f6\froman\fcharset1\fprq2 Georgia;}
      {\f7\ffroman\fcharset1\fprq2 Cambria;}
      {\f8\fmodern\fcharset0\fprq2 Courier New;}
      {\f9\ftech\fcharset2\fprq2 Symbol;}
      }
      
      
      \paperw15840\paperh12240\landscape
      
      \margl1440\margr1440\margt2880\margb1800\headery1800\footery1800
      
      {\pard\hyphpar\sb180\sa180\fi0\li0\ri0\qc\fs24{\f0 Participant by Age Category and Sex}\line\fs24{\f0 All Participants as Treated}\par}
      
      
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrb\brdrw15\clvertalb\cellx1749
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrb\brdrw15\clvertalb\cellx5246
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrb\brdrw15\clvertalb\cellx8743
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx12240
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Placebo}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Low Dose}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 High Dose}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalb\cellx1749
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx3498
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx5247
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx6996
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx8745
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx10494
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx12243
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Female}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Male}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Female}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Male}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Female}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Male}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalb\cellx1749
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx2623
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx3497
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx4371
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx5245
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx6119
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx6993
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx7867
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx8741
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx9615
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx10489
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx11363
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx12237
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1749
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2623
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3497
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4371
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5245
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6119
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6993
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7867
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8741
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9615
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10489
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11363
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12237
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 Participants in population}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 53}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 33}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 50}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 34}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 40}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 44}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 Age (years)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1749
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2623
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3497
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4371
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5245
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6119
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6993
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7867
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8741
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9615
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10489
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11363
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12237
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs16{\f0 <65}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 9}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (17.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 5}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (15.2)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 5}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (10.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 3}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  (8.8)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 5}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (12.5)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 6}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (13.6)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1749
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2623
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3497
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4371
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5245
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6119
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6993
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7867
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8741
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9615
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10489
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11363
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12237
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs16{\f0 65-80}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 22}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (41.5)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 20}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (60.6)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 28}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (56.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 19}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (55.9)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 28}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (70.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 27}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (61.4)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1749
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2623
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3497
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4371
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5245
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6119
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6993
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7867
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8741
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9615
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10489
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11363
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12237
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs16{\f0 >80}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 22}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (41.5)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 8}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (24.2)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 17}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (34.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 12}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (35.3)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 7}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (17.5)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 11}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (25.0)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1749
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2623
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3497
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4371
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5245
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6119
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6993
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7867
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8741
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9615
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10489
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11363
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12237
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1749
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2623
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3497
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4371
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5245
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6119
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6993
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7867
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8741
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9615
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10489
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11363
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12237
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs16{\f0 Mean}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 76.4}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 73.4}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 75.7}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 75.6}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 74.7}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 74.1}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1749
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2623
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3497
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4371
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5245
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6119
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6993
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7867
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8741
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9615
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10489
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11363
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12237
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs16{\f0 SD}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 8.7}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 8.1}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 8.1}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 8.7}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 7.7}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 8.2}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1749
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2623
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3497
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4371
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5245
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6119
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6993
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7867
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8741
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9615
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10489
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11363
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12237
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs16{\f0 Median}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 78.0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 74.0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 77.5}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 77.5}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 76.0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 77.0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx1749
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx2623
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx3497
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx4371
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx5245
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx6119
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx6993
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx7867
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx8741
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx9615
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx10489
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx11363
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx12237
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs16{\f0 Range}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 59 to 89}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 52 to 85}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 54 to 87}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 51 to 88}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 56 to 88}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 56 to 86}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrdb\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 SD=Standard deviation.}\cell
      \intbl\row\pard
      {\pard\hyphpar\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Source:  [CDISCpilot: adam-adsl]}\par}
      
      }

# rtf output: n and prop not including subgroup total w/ total

    Code
      writeLines(rtf_content)
    Output
      {\rtf1\ansi
      \deff0\deflang1033
      {\fonttbl{\f0\froman\fcharset1\fprq2 Times New Roman;}
      {\f1\froman\fcharset161\fprq2 Times New Roman Greek;}
      {\f2\fswiss\fcharset161\fprq2 Arial Greek;}
      {\f3\fswiss\fcharset0\fprq2 Arial;}
      {\f4\fswiss\fcharset1\fprq2 Helvetica;}
      {\f5\fswiss\fcharset1\fprq2 Calibri;}
      {\f6\froman\fcharset1\fprq2 Georgia;}
      {\f7\ffroman\fcharset1\fprq2 Cambria;}
      {\f8\fmodern\fcharset0\fprq2 Courier New;}
      {\f9\ftech\fcharset2\fprq2 Symbol;}
      }
      
      
      \paperw15840\paperh12240\landscape
      
      \margl1440\margr1440\margt2880\margb1800\headery1800\footery1800
      
      {\pard\hyphpar\sb180\sa180\fi0\li0\ri0\qc\fs24{\f0 Participant by Age Category and Sex}\line\fs24{\f0 All Participants as Treated}\par}
      
      
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrb\brdrw15\clvertalb\cellx1224
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrb\brdrw15\clvertalb\cellx4896
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrb\brdrw15\clvertalb\cellx8568
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx12240
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Placebo}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Low Dose}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 High Dose}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalb\cellx1224
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx2448
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx3672
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx4896
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx6120
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx7344
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx8568
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx9792
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx11016
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx12240
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Female}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Male}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Total}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Female}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Male}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Total}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Female}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Male}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Total}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalb\cellx1224
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx1836
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx2448
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx3060
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx3672
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx4284
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx4896
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx5508
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx6120
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx6732
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx7344
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx7956
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx8568
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx9180
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx9792
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx10404
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx11016
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx11628
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx12240
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1224
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1836
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2448
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3060
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3672
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4284
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4896
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5508
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6120
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6732
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7344
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7956
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8568
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9180
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9792
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10404
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11016
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11628
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 Participants in population}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 53}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 33}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 86}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 50}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 34}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 84}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 40}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 44}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 84}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 Age (years)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1224
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1836
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2448
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3060
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3672
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4284
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4896
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5508
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6120
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6732
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7344
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7956
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8568
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9180
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9792
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10404
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11016
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11628
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs16{\f0 <65}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 9}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (17.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 5}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (15.2)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 14}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (16.3)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 5}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (10.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 3}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  (8.8)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 8}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  (9.5)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 5}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (12.5)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 6}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (13.6)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 11}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (13.1)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1224
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1836
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2448
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3060
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3672
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4284
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4896
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5508
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6120
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6732
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7344
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7956
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8568
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9180
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9792
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10404
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11016
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11628
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs16{\f0 65-80}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 22}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (41.5)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 20}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (60.6)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 42}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (48.8)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 28}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (56.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 19}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (55.9)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 47}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (56.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 28}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (70.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 27}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (61.4)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 55}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (65.5)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1224
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1836
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2448
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3060
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3672
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4284
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4896
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5508
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6120
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6732
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7344
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7956
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8568
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9180
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9792
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10404
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11016
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11628
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs16{\f0 >80}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 22}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (41.5)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 8}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (24.2)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 30}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (34.9)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 17}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (34.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 12}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (35.3)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 29}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (34.5)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 7}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (17.5)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 11}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (25.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 18}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (21.4)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1224
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1836
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2448
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3060
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3672
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4284
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4896
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5508
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6120
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6732
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7344
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7956
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8568
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9180
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9792
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10404
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11016
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11628
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1224
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1836
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2448
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3060
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3672
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4284
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4896
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5508
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6120
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6732
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7344
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7956
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8568
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9180
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9792
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10404
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11016
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11628
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs16{\f0 Mean}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 76.4}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 73.4}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 75.2}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 75.7}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 75.6}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 75.7}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 74.7}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 74.1}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 74.4}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1224
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1836
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2448
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3060
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3672
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4284
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4896
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5508
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6120
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6732
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7344
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7956
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8568
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9180
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9792
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10404
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11016
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11628
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs16{\f0 SD}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 8.7}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 8.1}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 8.6}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 8.1}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 8.7}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 8.3}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 7.7}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 8.2}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 7.9}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1224
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1836
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2448
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3060
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3672
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4284
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4896
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5508
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6120
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6732
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7344
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7956
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8568
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9180
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9792
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10404
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11016
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11628
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs16{\f0 Median}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 78.0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 74.0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 76.0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 77.5}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 77.5}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 77.5}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 76.0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 77.0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 76.0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx1224
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx1836
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx2448
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx3060
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx3672
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx4284
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx4896
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx5508
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx6120
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx6732
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx7344
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx7956
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx8568
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx9180
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx9792
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx10404
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx11016
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx11628
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs16{\f0 Range}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 59 to 89}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 52 to 85}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 52 to 89}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 54 to 87}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 51 to 88}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 51 to 88}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 56 to 88}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 56 to 86}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 56 to 88}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrdb\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 SD=Standard deviation.}\cell
      \intbl\row\pard
      {\pard\hyphpar\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Source:  [CDISCpilot: adam-adsl]}\par}
      
      }

# rtf output: no group/subgroup total when a subgroup has no subject

    Code
      writeLines(rtf_content)
    Output
      {\rtf1\ansi
      \deff0\deflang1033
      {\fonttbl{\f0\froman\fcharset1\fprq2 Times New Roman;}
      {\f1\froman\fcharset161\fprq2 Times New Roman Greek;}
      {\f2\fswiss\fcharset161\fprq2 Arial Greek;}
      {\f3\fswiss\fcharset0\fprq2 Arial;}
      {\f4\fswiss\fcharset1\fprq2 Helvetica;}
      {\f5\fswiss\fcharset1\fprq2 Calibri;}
      {\f6\froman\fcharset1\fprq2 Georgia;}
      {\f7\ffroman\fcharset1\fprq2 Cambria;}
      {\f8\fmodern\fcharset0\fprq2 Courier New;}
      {\f9\ftech\fcharset2\fprq2 Symbol;}
      }
      
      
      \paperw15840\paperh12240\landscape
      
      \margl1440\margr1440\margt2880\margb1800\headery1800\footery1800
      
      {\pard\hyphpar\sb180\sa180\fi0\li0\ri0\qc\fs24{\f0 Participant by Age Category and Sex}\line\fs24{\f0 All Participants as Treated}\par}
      
      
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrb\brdrw15\clvertalb\cellx1749
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrb\brdrw15\clvertalb\cellx5246
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrb\brdrw15\clvertalb\cellx8743
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx12240
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Placebo}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Low Dose}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 High Dose}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalb\cellx1749
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx3498
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx5247
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx6996
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx8745
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx10494
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx12243
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Female}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Male}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Female}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Male}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Female}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Male}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalb\cellx1749
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx2623
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx3497
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx4371
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx5245
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx6119
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx6993
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx7867
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx8741
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx9615
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx10489
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx11363
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx12237
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1749
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2623
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3497
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4371
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5245
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6119
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6993
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7867
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8741
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9615
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10489
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11363
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12237
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 Participants in population}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 53}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 33}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 50}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 34}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 40}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 44}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 Race}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1749
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2623
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3497
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4371
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5245
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6119
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6993
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7867
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8741
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9615
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10489
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11363
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12237
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs16{\f0 AMERICAN INDIAN OR ALASKA NATIVE}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  (0.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  (0.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  (0.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0   (0.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  (0.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  1}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  (2.3)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1749
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2623
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3497
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4371
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5245
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6119
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6993
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7867
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8741
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9615
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10489
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11363
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12237
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs16{\f0 BLACK OR AFRICAN AMERICAN}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  5}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  (9.4)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  3}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  (9.1)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  6}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (12.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0   (0.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  6}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (15.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  3}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  (6.8)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx1749
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx2623
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx3497
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx4371
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx5245
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx6119
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx6993
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx7867
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx8741
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx9615
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx10489
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx11363
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx12237
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs16{\f0 WHITE}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 48}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (90.6)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 30}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (90.9)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 44}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (88.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 34}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (100.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 34}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (85.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 40}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (90.9)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrdb\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 SD=Standard deviation.}\cell
      \intbl\row\pard
      {\pard\hyphpar\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Source:  [CDISCpilot: adam-adsl]}\par}
      
      }

# rtf output: group/subgroup total when a subgroup has no subject

    Code
      writeLines(rtf_content)
    Output
      {\rtf1\ansi
      \deff0\deflang1033
      {\fonttbl{\f0\froman\fcharset1\fprq2 Times New Roman;}
      {\f1\froman\fcharset161\fprq2 Times New Roman Greek;}
      {\f2\fswiss\fcharset161\fprq2 Arial Greek;}
      {\f3\fswiss\fcharset0\fprq2 Arial;}
      {\f4\fswiss\fcharset1\fprq2 Helvetica;}
      {\f5\fswiss\fcharset1\fprq2 Calibri;}
      {\f6\froman\fcharset1\fprq2 Georgia;}
      {\f7\ffroman\fcharset1\fprq2 Cambria;}
      {\f8\fmodern\fcharset0\fprq2 Courier New;}
      {\f9\ftech\fcharset2\fprq2 Symbol;}
      }
      
      
      \paperw15840\paperh12240\landscape
      
      \margl1440\margr1440\margt2880\margb1800\headery1800\footery1800
      
      {\pard\hyphpar\sb180\sa180\fi0\li0\ri0\qc\fs24{\f0 Participant by Age Category and Sex}\line\fs24{\f0 All Participants as Treated}\par}
      
      
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrb\brdrw15\clvertalb\cellx942
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrb\brdrw15\clvertalb\cellx3767
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrb\brdrw15\clvertalb\cellx6592
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrb\brdrw15\clvertalb\cellx9417
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx12242
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Placebo}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Low Dose}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 High Dose}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Total}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalb\cellx942
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx1884
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx2826
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx3768
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx4710
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx5652
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx6594
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx7536
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx8478
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx9420
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx10362
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx11304
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx12246
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Female}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Male}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Total}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Female}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Male}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Total}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Female}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Male}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Total}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Female}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Male}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Total}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalb\cellx942
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx1413
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx1884
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx2355
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx2826
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx3297
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx3768
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx4239
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx4710
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx5181
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx5652
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx6123
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx6594
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx7065
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx7536
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx8007
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx8478
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx8949
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx9420
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx9891
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx10362
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx10833
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx11304
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx11775
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx12246
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx942
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1413
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1884
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2355
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2826
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3297
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3768
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4239
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4710
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5181
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5652
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6123
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6594
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7065
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7536
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8007
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8478
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8949
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9420
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9891
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10362
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10833
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11304
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11775
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12246
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 Participants in population}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 53}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 33}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 86}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 50}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 34}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 84}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 40}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 44}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 84}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 143}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 111}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 254}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 Race}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx942
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1413
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1884
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2355
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2826
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3297
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3768
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4239
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4710
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5181
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5652
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6123
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6594
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7065
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7536
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8007
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8478
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8949
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9420
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9891
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10362
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10833
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11304
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11775
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12246
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs16{\f0 AMERICAN INDIAN OR ALASKA NATIVE}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  (0.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  (0.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  (0.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  (0.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0   (0.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  (0.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  (0.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  1}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  (2.3)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  1}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  (1.2)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0   0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  (0.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0   1}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  (0.9)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0   1}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  (0.4)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx942
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1413
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1884
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2355
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2826
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3297
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3768
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4239
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4710
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5181
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5652
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6123
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6594
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7065
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7536
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8007
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8478
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8949
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9420
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9891
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10362
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10833
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11304
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11775
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12246
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs16{\f0 BLACK OR AFRICAN AMERICAN}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  5}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  (9.4)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  3}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  (9.1)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  8}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  (9.3)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  6}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (12.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0   (0.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  6}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  (7.1)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  6}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (15.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  3}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  (6.8)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  9}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (10.7)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  17}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (11.9)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0   6}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  (5.4)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  23}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  (9.1)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx942
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx1413
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx1884
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx2355
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx2826
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx3297
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx3768
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx4239
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx4710
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx5181
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx5652
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx6123
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx6594
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx7065
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx7536
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx8007
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx8478
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx8949
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx9420
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx9891
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx10362
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx10833
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx11304
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx11775
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx12246
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs16{\f0 WHITE}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 48}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (90.6)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 30}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (90.9)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 78}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (90.7)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 44}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (88.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 34}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (100.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 78}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (92.9)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 34}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (85.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 40}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (90.9)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 74}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (88.1)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 126}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (88.1)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 104}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (93.7)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 230}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (90.6)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrdb\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 SD=Standard deviation.}\cell
      \intbl\row\pard
      {\pard\hyphpar\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Source:  [CDISCpilot: adam-adsl]}\par}
      
      }

