# rtf output: n, prop, total

    Code
      writeLines(rtf_content)
    Output
      {\rtf1\ansi
      \deff0\deflang1033
      {\fonttbl{\f0\froman\fcharset1\fprq2 Times New Roman;}
      {\f1\froman\fcharset161\fprq2 Times New Roman Greek;}
      {\f2\fswiss\fcharset161\fprq2 Arial Greek;}
      {\f3\fswiss\fcharset0\fprq2 Arial;}
      {\f4\fswiss\fcharset1\fprq2 Helvetica;}
      {\f5\fswiss\fcharset1\fprq2 Calibri;}
      {\f6\froman\fcharset1\fprq2 Georgia;}
      {\f7\ffroman\fcharset1\fprq2 Cambria;}
      {\f8\fmodern\fcharset0\fprq2 Courier New;}
      {\f9\ftech\fcharset2\fprq2 Symbol;}
      }
      
      
      \paperw15840\paperh12240\landscape
      
      \margl1440\margr1440\margt2880\margb1800\headery1800\footery1800
      
      {\pard\hyphpar\sb180\sa180\fi0\li0\ri0\qc\fs24{\f0 Summary of Treatment Compliance}\line\fs24{\f0 All Participants as Treated}\par}
      
      
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrb\brdrw15\clvertalb\cellx4080
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrb\brdrw15\clvertalb\cellx6120
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrb\brdrw15\clvertalb\cellx8160
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrb\brdrw15\clvertalb\cellx10200
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx12240
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 Placebo}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 Low Dose}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 High Dose}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 Total}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalb\cellx4080
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx5100
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx6120
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx7140
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx8160
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx9180
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx10200
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx11220
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx12240
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (%)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4080
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5100
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6120
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7140
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8160
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9180
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10200
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11220
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs18{\f0 Participants in population}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 86}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 84}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 84}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 254}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs18{\f0\b Compliance (Week 8)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4080
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5100
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6120
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7140
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8160
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9180
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10200
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11220
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 N}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 12}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (14.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 24}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (28.6)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 28}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (33.3)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 64}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (25.2)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4080
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5100
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6120
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7140
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8160
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9180
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10200
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11220
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 Y}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 74}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (86.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 60}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (71.4)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 56}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (66.7)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 190}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (74.8)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs18{\f0\b Compliance (Week 16)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4080
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5100
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6120
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7140
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8160
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9180
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10200
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11220
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 N}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 18}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (20.9)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 42}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (50.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 47}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (56.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 107}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (42.1)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4080
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5100
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6120
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7140
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8160
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9180
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10200
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11220
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 Y}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 68}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (79.1)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 42}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (50.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 37}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (44.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 147}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (57.9)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs18{\f0\b Compliance (Week 24)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4080
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5100
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6120
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7140
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8160
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9180
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10200
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11220
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 N}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 26}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (30.2)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 56}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (66.7)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 54}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (64.3)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 136}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (53.5)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrdb\brdrw15\clvertalt\cellx4080
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrdb\brdrw15\clvertalt\cellx5100
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrdb\brdrw15\clvertalt\cellx6120
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrdb\brdrw15\clvertalt\cellx7140
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrdb\brdrw15\clvertalt\cellx8160
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrdb\brdrw15\clvertalt\cellx9180
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrdb\brdrw15\clvertalt\cellx10200
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrdb\brdrw15\clvertalt\cellx11220
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrdb\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 Y}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 60}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (69.8)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 28}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (33.3)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 30}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (35.7)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 118}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (46.5)}\cell
      \intbl\row\pard
      
      {\pard\hyphpar\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 Source: [CDISCpilot: adam-adsl]}\par}
      
      }

# rtf output: n, prop, total (no display_stat)

    Code
      writeLines(rtf_content)
    Output
      {\rtf1\ansi
      \deff0\deflang1033
      {\fonttbl{\f0\froman\fcharset1\fprq2 Times New Roman;}
      {\f1\froman\fcharset161\fprq2 Times New Roman Greek;}
      {\f2\fswiss\fcharset161\fprq2 Arial Greek;}
      {\f3\fswiss\fcharset0\fprq2 Arial;}
      {\f4\fswiss\fcharset1\fprq2 Helvetica;}
      {\f5\fswiss\fcharset1\fprq2 Calibri;}
      {\f6\froman\fcharset1\fprq2 Georgia;}
      {\f7\ffroman\fcharset1\fprq2 Cambria;}
      {\f8\fmodern\fcharset0\fprq2 Courier New;}
      {\f9\ftech\fcharset2\fprq2 Symbol;}
      }
      
      
      \paperw15840\paperh12240\landscape
      
      \margl1440\margr1440\margt2880\margb1800\headery1800\footery1800
      
      {\pard\hyphpar\sb180\sa180\fi0\li0\ri0\qc\fs24{\f0 Summary of Treatment Compliance}\line\fs24{\f0 All Participants as Treated}\par}
      
      
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrb\brdrw15\clvertalb\cellx4080
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrb\brdrw15\clvertalb\cellx6120
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrb\brdrw15\clvertalb\cellx8160
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrb\brdrw15\clvertalb\cellx10200
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx12240
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 Placebo}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 Low Dose}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 High Dose}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 Total}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalb\cellx4080
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx5100
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx6120
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx7140
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx8160
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx9180
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx10200
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx11220
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx12240
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (%)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4080
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5100
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6120
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7140
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8160
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9180
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10200
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11220
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs18{\f0 Participants in population}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 86}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 84}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 84}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 254}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs18{\f0\b Compliance (Week 8)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4080
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5100
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6120
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7140
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8160
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9180
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10200
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11220
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 N}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 12}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (14.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 24}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (28.6)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 28}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (33.3)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 64}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (25.2)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4080
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5100
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6120
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7140
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8160
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9180
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10200
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11220
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 Y}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 74}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (86.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 60}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (71.4)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 56}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (66.7)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 190}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (74.8)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs18{\f0\b Compliance (Week 16)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4080
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5100
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6120
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7140
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8160
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9180
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10200
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11220
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 N}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 18}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (20.9)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 42}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (50.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 47}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (56.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 107}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (42.1)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4080
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5100
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6120
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7140
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8160
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9180
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10200
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11220
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 Y}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 68}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (79.1)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 42}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (50.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 37}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (44.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 147}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (57.9)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs18{\f0\b Compliance (Week 24)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4080
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5100
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6120
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7140
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8160
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9180
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10200
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11220
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 N}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 26}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (30.2)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 56}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (66.7)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 54}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (64.3)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 136}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (53.5)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrdb\brdrw15\clvertalt\cellx4080
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrdb\brdrw15\clvertalt\cellx5100
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrdb\brdrw15\clvertalt\cellx6120
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrdb\brdrw15\clvertalt\cellx7140
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrdb\brdrw15\clvertalt\cellx8160
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrdb\brdrw15\clvertalt\cellx9180
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrdb\brdrw15\clvertalt\cellx10200
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrdb\brdrw15\clvertalt\cellx11220
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrdb\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 Y}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 60}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (69.8)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 28}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (33.3)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 30}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (35.7)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 118}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (46.5)}\cell
      \intbl\row\pard
      
      {\pard\hyphpar\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 Source: [CDISCpilot: adam-adsl]}\par}
      
      }

