% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{metalite_sl_adexsum}
\alias{metalite_sl_adexsum}
\title{ADEXSUM dataset}
\format{
A data frame with 508 rows and 50 variables.
}
\source{
\url{https://github.com/phuse-org/phuse-scripts/tree/master/data/sdtm/cdiscpilot01}
}
\usage{
metalite_sl_adexsum
}
\value{
An analysis data frame.
}
\description{
A dataset containing exposure details in Basic Data Structure (BDS).
}
\keyword{datasets}
